@@ -21,7 +21,7 @@ from .nlte import NLTE
 logger = logging.getLogger(__name__)
 
 #:dict(str, int): Mask value specifier used in mob
-MASK_VALUES = {"bad": 0, "line": 1, "continuum": 2, "vrad": 3}
+MASK_VALUES = {"bad": 0, "line": 1, "continuum": 2, "vrad": 4}
 
 
 @CollectionFactory
@@ -566,6 +566,12 @@ class SME_Structure(Parameters):
             return None
         return self.mask == MASK_VALUES["continuum"]
 
+    @property
+    def mask_vrad(self):
+        if self.mask is None:
+            return None
+        return self.mask == MASK_VALUES["vrad"]
+
     @property
     def cscale_degree(self):
         """int: Polynomial degree of the continuum as determined by cscale_flag"""
